menu
dynamic_polls package
documentation
dynamic_polls.dart
dynamic_polls.dart
dark_mode
light_mode
dynamic_polls
library
Classes
ColumnWidget
DateStyle
DynamicPolls
A customizable widget for displaying and interacting with a poll.
OptionStyle
Defines the style configuration for a poll option widget.
Styles
The
Styles
class in Dart contains properties for different text styles used in a user interface design. A comprehensive style configuration class to manage and customize various visual components of a UI widget or screen.
TitleStyle
A style configuration class to customize the appearance of the title in a user interface component.
UserDataModel
VoteData
Represents the data for a vote.
VotesTextStyle
A style configuration class to customize the appearance of the votes text in a user interface component.
dynamic_polls package
documentation
dynamic_polls.dart
dynamic_polls
package
Libraries
dynamic_polls
dynamic_polls library